@@ -911,8 +911,11 @@ accessx_applet_add_stock_icons (AccessxStatusApplet *sapplet, GtkWidget *widget)
 		do {
 			char *filename, *tmp;
 			GtkIconSource *source = gtk_icon_source_new ();
-			tmp = g_strdup_printf (PIXMAPDIR"accessx-status-applet/%s", stock_icons[i].name);
-			filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+			tmp = g_strdup_printf (GNOME_PIXMAPSDIR
+					"/accessx-status-applet/%s",
+					stock_icons[i].name);
+			filename = gnome_program_locate_file (NULL,
+					GNOME_FILE_DOMAIN_PIXMAP, 
 					  tmp, 
 					  FALSE, NULL);
 			g_free (tmp);
@@ -1309,7 +1312,7 @@ accessx_status_applet_fill (PanelApplet *applet)
 				   G_CALLBACK (key_press_cb), sapplet);				   
 
 	panel_applet_setup_menu_from_file (sapplet->applet,
-                                           NULL,
+                                           DATADIR,
 				           "GNOME_AccessxApplet.xml",
                                            NULL,
 				           accessx_status_applet_menu_verbs,
