@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.98 2004/12/12 05:38:19 davyd Exp $ */
+/* $Id: weather.c,v 1.101 2005/01/13 12:03:09 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -753,7 +753,7 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
 
 	info->forecast = NULL;
 	if (info->radar != NULL) {
-	    gdk_pixmap_unref (info->radar);
+	    g_object_unref (info->radar);
 	    info->radar = NULL;
 	}
     }
@@ -901,7 +901,7 @@ WeatherInfo *weather_info_clone (const WeatherInfo *info)
 
     clone->radar = info->radar;
     if (clone->radar != NULL)
-	    gdk_pixmap_ref (clone->radar);
+	    g_object_ref (clone->radar);
 
     return clone;
 }
@@ -918,7 +918,7 @@ void weather_info_free (WeatherInfo *info)
     info->forecast = NULL;
 
     if (info->radar != NULL) {
-        gdk_pixmap_unref (info->radar);
+        g_object_unref (info->radar);
         info->radar = NULL;
     }
 	
@@ -983,6 +983,7 @@ const gchar *weather_info_get_location (WeatherInfo *info)
 const gchar *weather_info_get_update (WeatherInfo *info)
 {
     static gchar buf[200];
+    char *utf8, *timeformat;
 
     g_return_val_if_fail(info != NULL, NULL);
 
@@ -991,10 +992,24 @@ const gchar *weather_info_get_update (WeatherInfo *info)
 
     if (info->update != 0) {
         struct tm tm;
-        localtime_r(&info->update, &tm);
-        if (strftime(buf, sizeof(buf), _("%a, %b %d / %H:%M"), &tm) <= 0)
+        localtime_r (&info->update, &tm);
+	/* TRANSLATOR: this is a format string for strftime
+	 *             see `man 3 strftime` for more details
+	 */
+	timeformat = g_locale_from_utf8 (_("%a, %b %d / %H:%M"), -1,
+			NULL, NULL, NULL);
+	if (!timeformat) {
 		strcpy (buf, "???");
-	buf[sizeof(buf)-1] = '\0';
+	}
+	else if (strftime(buf, sizeof(buf), timeformat, &tm) <= 0) {
+		strcpy (buf, "???");
+	}
+	g_free (timeformat);
+
+	/* Convert to UTF-8 */
+	utf8 = g_locale_to_utf8 (buf, -1, NULL, NULL, NULL);
+	strcpy (buf, utf8);
+	g_free (utf8);
     } else {
         strncpy(buf, _("Unknown observation time"), sizeof (buf));
 	buf[sizeof(buf)-1] = '\0';
@@ -1310,7 +1325,7 @@ const gchar *weather_info_get_forecast (WeatherInfo *info)
     return info->forecast;
 }
 
-GdkPixmap *weather_info_get_radar (WeatherInfo *info)
+GdkPixbufAnimation *weather_info_get_radar (WeatherInfo *info)
 {
     g_return_val_if_fail(info != NULL, NULL);
     return info->radar;
@@ -1500,6 +1515,7 @@ void _weather_info_get_pixbuf (WeatherInfo *info, gboolean mini, GdkPixbuf **pix
 	                      || (current_time >= info->sunrise &&
 				  current_time < info->sunset);
             switch (sky) {
+	    case SKY_INVALID:
             case SKY_CLEAR:
 	        idx = useSun ? PIX_SUN : PIX_MOON;
                 break;
