@@ -1,8 +1,6 @@
 #ifndef __GLOBAL_H__
 #define __GLOBAL_H__
 
-#include <config.h>
-
 #include <gnome.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
@@ -16,7 +14,8 @@
 
 G_BEGIN_DECLS
 
-#define NCPUSTATES 4
+#define NCPUSTATES 5
+#define NGRAPHS 6
 
 typedef struct _MultiloadApplet MultiloadApplet;
 typedef struct _LoadGraph LoadGraph;
@@ -61,7 +60,7 @@ struct _MultiloadApplet
 {
 	PanelApplet *applet;
 	
-	LoadGraph *graphs[5];
+	LoadGraph *graphs[NGRAPHS];
 	
 	GtkWidget *box;
 	
@@ -70,8 +69,11 @@ struct _MultiloadApplet
 	gboolean view_netload;
 	gboolean view_swapload;
 	gboolean view_loadavg;
+	gboolean view_diskload;
 	
-	GtkWidget *check_boxes[5];
+	GtkWidget *about_dialog;
+	GtkWidget *check_boxes[NGRAPHS];
+	GtkWidget *prop_dialog;
 };
 
 #include "load-graph.h"
@@ -97,13 +99,15 @@ netload_applet_new(PanelApplet *applet, gpointer data);
 LoadGraph *
 loadavg_applet_new(PanelApplet *applet, gpointer data);
 
-/* run procman, gtop's replacement */
-void
-start_procman_cb (BonoboUIComponent *uic, gpointer data, const gchar *name);
+/* start a new instance of the loadavg applet */
+LoadGraph *
+diskload_applet_new(PanelApplet *applet, gpointer data);
 
 /* show properties dialog */
 void
-multiload_properties_cb(BonoboUIComponent *uic, gpointer data, const gchar *name);
+multiload_properties_cb (BonoboUIComponent *uic,
+			 MultiloadApplet   *ma,	
+			 const char        *name);
 
 /* remove the old graphs and rebuild them */
 void
